# lifehacks [![publish](https://github.com/mightbesimon/lifehacks/actions/workflows/publish.yml/badge.svg)](https://github.com/mightbesimon/lifehacks)

## Structure

```plaintext
📦 lifehacks
│
├── 📦 metaclasses
│   ├── meta
│   ├── enum
│   └── EnumException
│
└── 📦 colour
    ├── Colour
    ├── hsla
    ├── rgba
    │
    └── 📦 palette
        ├── Apple
        └── Mariana
```

## Usage

- [`lifehacks.metaclasses`](https://github.com/mightbesimon/lifehacks.metaclasses/#readme)
- [`lifehacks.colour`](https://github.com/mightbesimon/lifehacks.colour/#readme)

## Contributors

- **Simon** - [mightbesimon](https://github.com/mightbesimon)
- you?
